if not LibStub then error("shClock requires LibStub") end

---------CONFIG--------------

local showMilitary = false --> default: false = 12-hour time format || true: 24-hour time format
local showInvites = true --> default: true = shows pending calendar invites OR false; does NOT show calendar invites

---------END OF CONFIG ------

-- Where are those locals at??
local format = format
local lower = strlower
local sub = strsub
local tonumber = tonumber
local date = date
local GetLocale = GetLocale
local GetRealmName = GetRealmName
local numInvites = CalendarGetNumPendingInvites

local locale = GetLocale()
local realm = GetRealmName()
local shown

local icon = [=[Interface\AddOns\shClock\media\clock]=]
local icon2 = [=[Interface\AddOns\shClock\media\bubble]=]

local function GetTipAnchor(frame)
	local x,y = frame:GetCenter()
	if not x or not y then return "TOPLEFT", "BOTTOMLEFT" end
	local hhalf = (x > UIParent:GetWidth()*2/3) and "RIGHT" or (x < UIParent:GetWidth()/3) and "LEFT" or ""
	local vhalf = (y > UIParent:GetHeight()/2) and "TOP" or "BOTTOM"
	return vhalf..hhalf, frame, (vhalf == "TOP" and "BOTTOM" or "TOP")..hhalf
end

local function getHour(s)
	return tonumber(s) < 10 and sub(s,2) or s
end

local function formatLocal()
	local localTime
	if showMilitary then
		localTime = date("%H:%M")
	else
		localTime = format("%s:%s%s", getHour(date("%I")), date("%M"), lower(date("%p")))
	end	
	return localTime
end

local function formatRealm()
	local hour, minute = GetGameTime()
	if minute < 10 then minute = "0"..minute end
	
	if showMilitary then
		return format("%d:%d", hour, minute) 
	else
		if hour < 12 then
			return format("%d:%dam", hour, minute) 
		elseif hour == 12 then
			return format("12:%dpm", minute)
		elseif hour == 24 then
			return format("12:%dam", minute)			
		else
			return format("%d:%dpm", hour-12, minute)
		end
	end
end

local function formatUTC() 
	local utcTime
	if showMilitary then
		utcTime = date("!%H:%M")
	else 
		utcTime = format("%s:%s%s", getHour(date("!%I")), date("%M"), lower(date("!%p")))
	end	
	return utcTime		
end

-- create data broker ldb
local dclock = LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("shClock", {
	type = "data source", 
	text = "Initializing..", 
	icon = icon }) 
	
local fclock = CreateFrame("frame")

local timeController = 0	
local invites = 0
fclock:SetScript("OnUpdate", function(self, elap)
	timeController = timeController + elap
	if timeController < 1 then return end
	
	invites = numInvites()
	
	if invites > 0 and showInvites then
		dclock.icon = icon2
		dclock.text = format("|cff0deb11%s invite(s)!|r |cffFFFF00%s|r", invites, formatLocal())
	else
		dclock.icon = icon
		dclock.text = formatLocal()
	end
	
	if shown then dclock.OnEnter(shown) end
	timeController = 0
end)

function dclock.OnLeave()
	GameTooltip:Hide()
	shown = nil
end

function dclock.OnEnter(self)
	shown = self
	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint(GetTipAnchor(self))
	GameTooltip:ClearLines()
		
	GameTooltip:AddLine("|cff0062ffsh|r|cff0DEB11Clock|r")
	GameTooltip:AddLine("[Date/Time]\n")
	if invites > 0 then
		GameTooltip:AddLine(format("|cffff3c00**You have |cff0deb11%d pending|r |cffff3c00invitation(s)!**|r", invites))
	end
	
	--GameTooltip:AddLine("|cffc3771aDataBroker|r based addon to show|cff06DDFAtime/date related|r information\n") 
	
	GameTooltip:AddDoubleLine("Locale/Realm Name:\n", format("|cff0deb11%s - %s|r\n", locale, realm))
	
	local cdate = date("|cffc3771a%A|r, |cff0deb11%B %d, %Y|r")
	GameTooltip:AddDoubleLine(cdate, " ")
	GameTooltip:AddLine("----------------")
	
	GameTooltip:AddDoubleLine("|cff06ddfaRealm|r |cffffffffTime:|r", formatRealm())	
	GameTooltip:AddDoubleLine("|cff0deb11Local|r |cffffffffTime:|r", formatLocal())
	GameTooltip:AddDoubleLine("UTC |cffffffffTime:|r", formatUTC())
	
	GameTooltip:AddLine(" ")
	
	GameTooltip:AddLine("|cff0deb11Left Click:|r toggle |cffc3771aTime Manager|r")
	GameTooltip:AddLine("|cff06ddfaRight Click:|r toggle |cffc3771aCalendar|r")
	
	GameTooltip:Show()
end

function dclock.OnClick(self, button)
	if button == "LeftButton" then
		ToggleTimeManager()
	elseif button == "RightButton" then
		ToggleCalendar()
	end
end
